import * as vscode from 'vscode';
import * as assert from 'assert';
import { getDocUri, activate } from './helper';

suite('Should do completion', () => {
  const docUri = getDocUri('completion.txt');

  // 1行目にカーソルを置いて、"VS Code"コード補完が起動するか検証
  test('Completes VS Code', async () => {
    await testCompletion(docUri, new vscode.Position(0, 0), {
      items: [
        {
          label: 'Visual Studio Code',
          kind: vscode.CompletionItemKind.Text,
        },
      ],
    });
  });
  // 2行目にカーソルを置いて、ファイル名をコード補完するか検証
  test('Completes file name', async () => {
    await testCompletion(docUri, new vscode.Position(1, 0), {
      items: [
        { label: 'completion.txt', kind: vscode.CompletionItemKind.Text },
      ],
    });
  });
});

async function testCompletion(
  docUri: vscode.Uri,
  position: vscode.Position,
  expectedCompletionList: vscode.CompletionList
) {
  await activate(docUri);

  // `vscode.executeCompletionItemProvider`でコード補完を実行する
  const actualCompletionList = (await vscode.commands.executeCommand(
    'vscode.executeCompletionItemProvider',
    docUri,
    position
  )) as vscode.CompletionList;

  expectedCompletionList.items.forEach((expectedItem, i) => {
    const actualItem = actualCompletionList.items[i];
    assert.equal(actualItem.label, expectedItem.label);
    assert.equal(actualItem.kind, expectedItem.kind);
  });
}
