import { 
	commands, env,
	ExtensionContext,
	StatusBarAlignment, StatusBarItem,
	TextEditor,
	window }from 'vscode';

// 利用するステータスバーのアイテム
let myStatusBarItem: StatusBarItem;

export function activate(context: ExtensionContext) {
  // ステータスバーのアイテムクリック時に呼ばれる関数の定義
  const myCommandId = 'my-editor-ui.copySelectedLines';
  context.subscriptions.push(commands.registerCommand(myCommandId, () => {
    // 選択中の範囲を文字列として取得する
    const content = window.activeTextEditor?.document.getText(
      window.activeTextEditor?.selection
    );
    if (content) {
      // 選択中の範囲をクリップボードに書き込む
      env.clipboard.writeText(content);
      window.showInformationMessage(`選択範囲をコピーしました`);
    }
  }));

  // ステータスバーアイテムの作成、100は表示優先度の値で大きいほど優先度は低め
  myStatusBarItem = window.createStatusBarItem(
	StatusBarAlignment.Right, 100
  );
  myStatusBarItem.command = myCommandId;
  context.subscriptions.push(myStatusBarItem);

  // ステータスバーアイテムのリスナーを登録し、ステータスバーを更新する
  context.subscriptions.push(
	window.onDidChangeActiveTextEditor(updateStatusBarItem),
	window.onDidChangeTextEditorSelection(updateStatusBarItem)
  );

  // 起動時にステータスバーのアイテムを更新
  updateStatusBarItem();
}

// ステータスバーの表示切り替えを行う
function updateStatusBarItem(): void {
  const n = getNumberOfSelectedLines(window.activeTextEditor);
  if (n > 0) {
    myStatusBarItem.text = `$(megaphone) ${n} 行を選択中`;
    myStatusBarItem.show();
  } else {
    myStatusBarItem.hide();
  }
}

// 現在選択中の行数を取得する
export function getNumberOfSelectedLines(editor?: TextEditor): number {
  let lines = 1;
  if (editor) {
    lines = editor.selections.reduce((prev, curr) => 
	  prev + (curr.end.line - curr.start.line), 0
	) + 1;
  }
  return lines;
}