import * as assert from 'assert';

import * as vscode from 'vscode';
import * as path from 'path';
// 拡張機能を読み込む
import * as myExtension from '../../extension';

export let editor: vscode.TextEditor;

suite('Calculate selected lines', () => {
  // 対象とするファイルのパスを取得する
  const docPath = path.resolve(
    __dirname,
    '../../../src/test/testFixture',
    'uitest.txt');
  // 対象とするファイルの識別子 （URI: Uniform Resource Identifier） を取得
  const docUri =  vscode.Uri.file(docPath);

  test('UI extension function test', async () => {
    await testExtension(docUri);
  });
});

async function testExtension(docUri: vscode.Uri) {
  // ファイルを開く
  await activate(docUri);
  // Built-in Commandsからカーソルを操作するコマンドを呼び出す
  // カーソルを1つだけ選択しながら移動する
  await vscode.commands.executeCommand(
    'cursorMove', { to: 'down', select: true });
  // 拡張機能のgetNumberOfSelectedLines関数を呼び出す
  const number1 = myExtension.getNumberOfSelectedLines(editor);
  // 選択行数が2行であるか確認する
  assert.strictEqual(number1, 2);

  // 最終行までカーソルを移動
  await vscode.commands.executeCommand(
    'cursorMove', { to: 'viewPortBottom', select: true });
  const number2 = myExtension.getNumberOfSelectedLines(editor);
  assert.strictEqual(number2, 5);
}

export async function activate(docUri: vscode.Uri) {
  // package.jsonで定義したnameとpublisherの組み合わせでextensionIdを生成
  const ext = vscode.extensions.getExtension('ikuyadeu.my-editor-ui')!;
  await ext.activate();
  try {
    // 対象とするファイルを開く
    const doc = await vscode.workspace.openTextDocument(docUri);
    // 対象とするエディターを開く
    editor = await vscode.window.showTextDocument(doc);
     // 拡張機能が有効になるのを待つ
    await new Promise(resolve => setTimeout(resolve, 2000));
  } catch (e) {
    console.error(e);
  }
}